api.customernetworks.v1 package — Argus-Toolbelt 1.0 documentation

# api.customernetworks.v1 package

## Submodules

## api.customernetworks.v1.network module

Autogenerated API

`api.customernetworks.v1.network.` `add_customer_network`(customer: str = None, location: str = None, flagsToEnable: list = None, zone: str = None, description: str = None, networkAddress: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | customer (str) – Customer ID or short name of the customer that the network belongs to location (str) – Location ID or short name of the location where the network is located flagsToEnable (list) – Flags to enable for the network zone (str) – Zone of the network description (str) – Description of the customer network. Maximum number of characters is 255. => [sw{}$-().[]“‘_/,*+#:@!?;]* networkAddress (str) – IP address of the customer network => format:ip
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 931, “limit”: 840, “responseCode”: 200, “count”: 511, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Yet indicate while picture tax several local.”, “messageTemplate”: “Culture exactly detail worry usually possible right.”, “field”: “Name effort receive style or understand.”, “parameter”: {}, “timestamp”: 349320720}], “currentPage”: 426, “size”: 539}

`api.customernetworks.v1.network.` `add_customer_network_comment`(networkID: int, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add comment for customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to update comment (str) – Comment to add to the network => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 456, “limit”: 650, “responseCode”: 200, “count”: 264, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Issue example support perform run force.”, “messageTemplate”: “Establish me simply parent prevent.”, “field”: “Four husband knowledge pressure.”, “parameter”: {}, “timestamp”: 1333382307}], “currentPage”: 657, “size”: 138}

`api.customernetworks.v1.network.` `delete_customer_network`(networkID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to delete
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 380, “limit”: 983, “responseCode”: 200, “count”: 155, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Too anything but yeah worker last.”, “messageTemplate”: “Cell and cause job while.”, “field”: “Purpose area treatment drop various society let wind.”, “parameter”: {}, “timestamp”: 68196882}], “currentPage”: 606, “size”: 542}

`api.customernetworks.v1.network.` `delete_customer_network_comment`(networkID: int, commentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete comment from customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of parent network commentID (str) – ID of comment to delete
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 567, “limit”: 359, “responseCode”: 200, “count”: 147, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Decade defense take street.”, “messageTemplate”: “Nothing stuff our parent clearly home.”, “field”: “Speech former season break either never.”, “parameter”: {}, “timestamp”: 506178345}], “currentPage”: 495, “size”: 691}

`api.customernetworks.v1.network.` `get_customer_network`(networkID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to get
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 985, “limit”: 342, “responseCode”: 200, “count”: 380, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Large try myself artist job month.”, “messageTemplate”: “Say take laugh learn help nearly.”, “field”: “Add affect base road.”, “parameter”: {}, “timestamp”: 1028606948}], “currentPage”: 125, “size”: 632}

`api.customernetworks.v1.network.` `get_customer_network_comments`(networkID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get network’s comments (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network offset (int) – Skip a number of comments limit (int) – Maximum number of returned comments
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 711, “limit”: 143, “responseCode”: 200, “count”: 445, “data”: [{“id”: 114, “description”: “Cold all piece exactly.”, “lastUpdatedByUser”: {“id”: 392, “customerID”: 777, “userName”: “christopher19”, “name”: “Brett Davis”}, “lastUpdatedTimestamp”: 897674729, “createdByUser”: {“id”: 791, “customerID”: 960, “userName”: “iharvey”, “name”: “Paul Martinez”}, “createdTimestamp”: 813556167, “zone”: “DMZ”, “flags”: [“NAT”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Cause yes add old require morning it issue.”, “messageTemplate”: “Blue writer record mean determine price natural.”, “field”: “Factor rise smile man lead question.”, “parameter”: {}, “timestamp”: 915311923}], “currentPage”: 513, “size”: 276}

`api.customernetworks.v1.network.` `get_customer_networks`(customerID: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get networks belonging to customer(s) (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – ID of customer(s) offset (int) – Skip a number of networks limit (int) – Maximum number of returned networks
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 321, “limit”: 201, “responseCode”: 200, “count”: 747, “data”: [{“id”: 647, “description”: “Many send hair.”, “lastUpdatedByUser”: {“id”: 315, “customerID”: 728, “userName”: “whitekatherine”, “name”: “Jared Roth”}, “lastUpdatedTimestamp”: 1107412133, “createdByUser”: {“id”: 160, “customerID”: 528, “userName”: “aaron79”, “name”: “Jonathan Cook”}, “createdTimestamp”: 1131430514, “zone”: “DMZ”, “flags”: [“PROXY”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Same prevent few one.”, “messageTemplate”: “Somebody manage spend policy my bank.”, “field”: “Responsibility on training threat.”, “parameter”: {}, “timestamp”: 72210800}], “currentPage”: 14, “size”: 315}

`api.customernetworks.v1.network.` `search_customer_network`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, addresses: list = None, keywords: list = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, includeFlags: list = None, excludeFlags: list = None, includeSupernet: bool = 'True', includeSubnet: bool = 'True', timeMatchStrategy: str = 'any', includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. addresses (list) – A set of IP addresses matched against networks keywords (list) – A set of keywords matched against network’s description startTimestamp (int) – Start of time search period endTimestamp (int) – End of time search period timeFieldStrategy (list) – TimeFieldStrategy to define which timestamp field(s) to match. (default createdTimestamp) includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeSupernet (bool) – Network in search criteria will be searched for matching supernets (default true) includeSubnet (bool) – Network in search criteria will be searched for matching subnets (default true) timeMatchStrategy (str) – TimeMatchStrategy to define how to match startTimestamp and endTimestamp with provided timeFieldStrategies (default any) includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 87, “limit”: 303, “responseCode”: 200, “count”: 491, “data”: [{“id”: 962, “description”: “Sense fly world current between.”, “lastUpdatedByUser”: {“id”: 809, “customerID”: 611, “userName”: “amysimmons”, “name”: “Roger Fisher II”}, “lastUpdatedTimestamp”: 97777621, “createdByUser”: {“id”: 334, “customerID”: 390, “userName”: “jensencarl”, “name”: “Erica Garcia”}, “createdTimestamp”: 329734675, “zone”: “DMZ”, “flags”: [“SERVER”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Law subject son help.”, “messageTemplate”: “Foreign religious somebody organization against single defense.”, “field”: “Reflect look admit experience.”, “parameter”: {}, “timestamp”: 834275566}], “currentPage”: 784, “size”: 850}

`api.customernetworks.v1.network.` `update_customer_network`(networkID: int, location: str = None, description: str = None, flagsToEnable: list = None, flagsToDisable: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update customer network (PUBLIC)

  Return type: | `dict`
  Parameters: | networkID (int) – ID of network to update location (str) – Location ID or short name of the location where the network is located description (str) – Description of the customer network. Maximum number of characters is 255. => [sw{}$-().[]“‘_/,*+#:@!?;]* flagsToEnable (list) – Flags to enable for the network flagsToDisable (list) – Flags to disable for the network
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 65, “limit”: 485, “responseCode”: 200, “count”: 774, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Stage artist piece follow sign.”, “messageTemplate”: “Box as chair design evidence.”, “field”: “Popular quality them one easy investment pressure.”, “parameter”: {}, “timestamp”: 161432092}], “currentPage”: 703, “size”: 29}

## Module contents